@@ -70,13 +70,13 @@ public:
     /**
      * Destructs an unzoomed thumbnail view.
      */
-    virtual ~kpUnzoomedThumbnailView ();
+    ~kpUnzoomedThumbnailView () override;
 
 
     /**
      * Implements @ref kpThumbnailView.
      */
-    QString caption () const;
+    QString caption () const override;
 
 
 public slots:
@@ -95,7 +95,7 @@ public slots:
      *
      * Implements @ref kpView.
      */
-    virtual void adjustToEnvironment ();
+    void adjustToEnvironment () override;
 
 
 private:
